==> KidozSDK-0.5.4-sources.jar: com/kidoz/sdk/api/general/assets_handling/StyleParser.java <==
package com.kidoz.sdk.api.general.assets_handling;

import android.content.Context;

import com.kidoz.sdk.api.FlexiView;
import com.kidoz.sdk.api.KidozInterstitial;
import com.kidoz.sdk.api.general.database.DatabaseManager;
import com.kidoz.sdk.api.general.utils.SDKLogger;

import org.json.JSONObject;

/**
 * Created by Eugine on 3/28/2016.
 */
public final class StyleParser {

    public static final String STYLE_ID = "style_id";


    // Interstitial style handling
    public static final String INTERSTITIAL_VIEW_DURATION = "viewDurationSec";

    public static boolean parseInterstitialData(Context context, JSONObject jsonObject) {

        boolean result = false;
        if (jsonObject != null) {
            try {
                JSONObject oldData = DatabaseManager.getInstance(context).getConfigTable().loadProperties(KidozInterstitial.TAG);

               /* result = AssetUtil.loadAsset(context, oldData, jsonObject, ANIMATION_OVERLAY);
                if (result) {
                    result = AssetUtil.loadAsset(context, oldData, jsonObject, CLOSE_BTN);
                }*/

                // 4. Update database
                result = true;
                if (result == true) {
                    DatabaseManager.getInstance(context).getConfigTable().insertProperties(KidozInterstitial.TAG, jsonObject);
                }
            } catch (Exception ex) {
                result = false;
                SDKLogger.printErrorLog(FlexiView.TAG, "Error when trying to parse kidoz interstitial view properties" + ex.getMessage());
            }
        }

        return result;
    }





}

==> KidozSDK-0.6.0-sources.jar: com/kidoz/sdk/api/general/assets_handling/StyleParser.java <==
package com.kidoz.sdk.api.general.assets_handling;

import android.content.Context;

import com.kidoz.sdk.api.FlexiView;
import com.kidoz.sdk.api.KidozInterstitial;
import com.kidoz.sdk.api.general.database.DatabaseManager;
import com.kidoz.sdk.api.general.utils.SDKLogger;
import com.kidoz.sdk.api.ui_views.video_unit.VideoUnit;

import org.json.JSONObject;

/**
 * Created by Eugine on 3/28/2016.
 */
public final class StyleParser
{

    public static final String STYLE_ID = "style_id";


    // Interstitial style handling
    public static final String INTERSTITIAL_VIEW_DURATION = "viewDurationSec";

    public static boolean parseInterstitialData(Context context, JSONObject jsonObject)
    {

        boolean result = false;
        if (jsonObject != null)
        {
            try
            {
                JSONObject oldData = DatabaseManager.getInstance(context).getConfigTable().loadProperties(KidozInterstitial.TAG);

               /* result = AssetUtil.loadAsset(context, oldData, jsonObject, ANIMATION_OVERLAY);
                if (result) {
                    result = AssetUtil.loadAsset(context, oldData, jsonObject, CLOSE_BTN);
                }*/

                // 4. Update database
                result = true;
                if (result == true)
                {
                    DatabaseManager.getInstance(context).getConfigTable().insertProperties(KidozInterstitial.TAG, jsonObject);
                }
            }
            catch (Exception ex)
            {
                result = false;
                SDKLogger.printErrorLog(FlexiView.TAG, "Error when trying to parse kidoz interstitial view properties" + ex.getMessage());
            }
        }

        return result;
    }

    public static boolean parseVideoUnit(Context context, JSONObject jsonObject)
    {
        boolean result = false;
        if (jsonObject != null)
        {
            try
            {
                DatabaseManager.getInstance(context).getConfigTable().insertProperties(VideoUnit.TAG, jsonObject);
                result = true;
            }
            catch (Exception ex)
            {
                result = false;
                SDKLogger.printErrorLog(FlexiView.TAG, "Error when trying to parse kidoz video unit view properties" + ex.getMessage());
            }
        }
        return result;
    }
}
